==> designer-asset-1.0.10-20251203.101431-23-sources.jar: com/digiwin/athena/dto/assembly/solution/SolutionPlanListDTO.java <==
package com.digiwin.athena.dto.assembly.solution;

import cn.hutool.core.date.DatePattern;
import com.digiwin.athena.common.dict.Dict;
import com.digiwin.athena.constants.enums.assembly.AssemblyType;
import com.digiwin.athena.constants.enums.assembly.OnlineState;
import com.digiwin.athena.dto.action.MultiLanguageDTO;
import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.Data;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

/**
 * 解决方案列表DTO
 */
@Data
public class SolutionPlanListDTO {

    /**
     * ID
     */
    private String id;

    /**
     * 名称
     */
    private String name;

    /**
     * 编码
     */
    private String type;

    private Integer appType;

    /**
     * 组装方式
     * @see AssemblyType#getCode()
     */
    @Dict(enumClass = AssemblyType.class)
    private String assemblyType;

    /**
     * 关联设计器
     */
    private List<SolutionPlanDetailDTO.DesignerBaseInfoDTO> designerList;

    /**
     * 归属方
     */
    private String owner;

    /**
     * 状态
     * @see OnlineState#getCode()
     */
    @Dict(enumClass = OnlineState.class)
    private String status;

    /**
     * 版本
     */
    private String version;

    /**
     * true走标准发布，对应的应用类型会在运维中心体现
     */
    private Boolean isStdPublish;

    /**
     * 多语言配置
     */
    private Map<String, MultiLanguageDTO<String>> lang;

    /**
     * 发布时间
     */
    @JsonFormat(pattern = DatePattern.NORM_DATETIME_PATTERN)
    private LocalDateTime publishTime;
    /**
     * 发布人
     */
    private String publishBy;

    /**
     * 更新时间
     */
    @JsonFormat(pattern = DatePattern.NORM_DATETIME_PATTERN)
    private LocalDateTime editTime;
    /**
     * 更新人
     */
    private String editBy;

}

==> designer-asset-1.0.10-20251211.102111-50-sources.jar: com/digiwin/athena/dto/assembly/solution/SolutionPlanListDTO.java <==
package com.digiwin.athena.dto.assembly.solution;

import cn.hutool.core.date.DatePattern;
import com.digiwin.athena.common.dict.Dict;
import com.digiwin.athena.constants.enums.assembly.AssemblyType;
import com.digiwin.athena.constants.enums.assembly.OnlineState;
import com.digiwin.athena.dto.action.MultiLanguageDTO;
import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.Data;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

/**
 * 解决方案列表DTO
 */
@Data
public class SolutionPlanListDTO {

    /**
     * ID
     */
    private String id;

    /**
     * 名称
     */
    private String name;

    /**
     * 编码
     */
    private String type;

    private String category;
    private Integer appType;

    /**
     * 组装方式
     * @see AssemblyType#getCode()
     */
    @Dict(enumClass = AssemblyType.class)
    private String assemblyType;

    private SolutionPlanDetailDTO.SsoConfigDTO ssoConfig;              // SSO配置(不可组装页面配置)

    /**
     * 关联设计器
     */
    private List<SolutionPlanDetailDTO.DesignerBaseInfoDTO> designerList;

    /**
     * 归属方
     */
    private String owner;

    /**
     * 状态
     * @see OnlineState#getCode()
     */
    @Dict(enumClass = OnlineState.class)
    private String status;

    /**
     * 版本
     */
    private String version;

    /**
     * true走标准发布，对应的应用类型会在运维中心体现
     */
    private Boolean isStdPublish;

    /**
     * 多语言配置
     */
    private Map<String, MultiLanguageDTO<String>> lang;

    /**
     * 发布时间
     */
    @JsonFormat(pattern = DatePattern.NORM_DATETIME_PATTERN)
    private LocalDateTime publishTime;
    /**
     * 发布人
     */
    private String publishBy;

    /**
     * 更新时间
     */
    @JsonFormat(pattern = DatePattern.NORM_DATETIME_PATTERN)
    private LocalDateTime editTime;
    /**
     * 更新人
     */
    private String editBy;

}
